@@ -340,6 +340,9 @@ extern float TCTime;
 extern int phase;
 
 extern short bookfirstlast;
+extern short graphicmodeoutput;
+extern short pgnloaded; /* was pgn game loaded by command pgnreplay */
+extern int pgncnt; /* total moves loaded in pgn game */
 
 extern int range[8];
 extern int ptype[2];
@@ -457,7 +460,7 @@ short ValidateBoard (void);
 
 /*  PGN routines  */
 void PGNSaveToFile (const char *, const char *);
-void PGNReadFromFile (const char *);
+void PGNReadFromFile (const char *, int showheading);
 
 /*  Some output routines */
 void ShowMoveList (int);
@@ -488,6 +491,9 @@ extern char inputstr[BUF_SIZE];
 /* Input parser */
 void parse_input(void);
 
+/* Check Board to avoid analysis of incorrectly input positions */
+void check_board(void);
+
 /* Commands from the input engine */
 void cmd_activate(void); 
 void cmd_analyze(void);
@@ -503,24 +509,31 @@ void cmd_epd(void);
 void cmd_exit(void);
 void cmd_force(void);
 void cmd_go(void);
+void cmd_graphic(void);
 void cmd_hard(void);
 void cmd_hash(void);
 void cmd_help (void);
 void cmd_hint(void);
+void cmd_last(void);
 void cmd_level(void);
 void cmd_list(void);
 void cmd_load(void);
 void cmd_manual(void);
 void cmd_movenow(void);
 void cmd_name(void);
+void cmd_next(void);
 void cmd_new(void);
+void cmd_nographic(void);
 void cmd_nopost(void);
 void cmd_null(void);
 void cmd_otim(void);
 void cmd_pgnload(void);
+void cmd_pgnreplay(void);
 void cmd_pgnsave(void);
 void cmd_ping(void);
 void cmd_post(void);
+void cmd_previous(void);
+void cmd_first(void);
 void cmd_protover(void);
 void cmd_quit(void);
 void cmd_random(void);
@@ -543,6 +556,7 @@ void cmd_version(void);
 void cmd_white(void);
 void cmd_xboard(void);
 
+
 /*
  * Define NO_INLINE only if you really must, implementations will be
  * provided by the corresponding *.c files. The better solution is to
